@@ -9,3 +9,16 @@ def assert_json(check: dict, expt: dict):
         else:
             assert check[e_key] == expt_elm, f"\nkey = [{e_key}]\nexpect =>  \n{expt_elm}\ncheck => \n{check[e_key]}" \
                                              f"\n------\nexpect_json =>  \n{expt}\ncheck_json => \n{check}"
+
+def is_db_id(did: str) -> bool:
+    if did is None:
+        return False
+    if len(did) == 0:
+        return False
+    if did[0] != 'i':
+        return False
+    try:
+        n = int(did[1:])
+        return True
+    except ValueError:
+        return False
